pub struct DetectionOptions {
pub analysis_speed: SceneDetectionSpeed,
pub detect_flashes: bool,
pub min_scenecut_distance: Option<usize>,
pub max_scenecut_distance: Option<usize>,
pub lookahead_distance: usize,
}Expand description
Options determining how to run scene change detection.
Fields
analysis_speed: SceneDetectionSpeedThe speed of detection algorithm to use. Slower algorithms are more accurate/better for use in encoders.
detect_flashes: boolEnabling this will utilize heuristics to avoid scenecuts that are too close to each other. This is generally useful if you want scenecut detection for use in an encoder. If you want a raw list of scene changes, you should disable this.
min_scenecut_distance: Option<usize>The minimum distance between two scene changes.
max_scenecut_distance: Option<usize>The maximum distance between two scene changes.
lookahead_distance: usizeThe distance to look ahead in the video for scene flash detection.
Not used if detect_flashes is false.